{% extends 'generic/object.html' %}

{% block content %}
  <div class="row mb-3">
    <div class="col col-md-6">
      <div class="card">
        <h5 class="card-header">Storage Session</h5>
        <div class="card-body">
          <table class="table table-hover attr-table">
            <tr>
              <th scope="row">Name</th>
              <td>{{ object.name }}</td>
            </tr>
            <tr>
              <th scope="row">Cluster</th>
              <td><a href="{{ object.cluster.get_absolute_url }}">{{ object.cluster }}</a></td>
            </tr>
            <tr>
              <th scope="row">Datastores</th>
              <td>
                {% for datastore in object.datastores.all %}
                  <a href="{{ datastore.get_absolute_url }}">{{ datastore }}</a>
                  {% if not forloop.last %}, {% endif %}
                {% endfor %}
              </td>
            </tr>
            <tr>
              <th scope="row">Description</th>
              <td>{{ object.description }}</td>
            </tr>
          </table>
        </div>
      </div>
      {% include 'inc/panels/custom_fields.html' %}
    </div>
    <div class="col col-md-6">
      {% include 'inc/panels/tags.html' %}
    </div>
  </div>
{% endblock content %}