{% extends 'generic/object.html' %}
{% load render_table from django_tables2 %}
{% load helpers %}

{% block content %}
  <div class="row mb-3">
    <div class="col col-md-6">
      <div class="card">
        <h5 class="card-header">Storage LUN</h5>
        <div class="card-body">
          <table class="table table-hover attr-table">
            <tr>
              <th scope="row">Name</th>
              <td>{{ object.name }}</td>
            </tr>
            <tr>
              <th scope="row">Storage pool</th>
              <td>
                <a href="{{ object.storage_pool.get_absolute_url }}">{{ object.storage_pool }}</a>
              </td>
            </tr>
            <tr>
              <th scope="row">Size</th>
              <td>{{ object.size }} GB</td>
            </tr>
            <tr>
              <th scope="row">Description</th>
              <td>{{ object.description }}</td>
            </tr>
          </table>
        </div>
      </div>
      {% include 'inc/panels/custom_fields.html' %}
    </div>
    <div class="col col-md-6">
      {% include 'inc/panels/tags.html' %}
    </div>
  </div>
  {% comment %}
  <div class="row">
    <div class="col col-md-12">
      <div class="card">
        <h5 class="card-header">Storage Space Allocations</h5>
        <div class="card-body table-responsive">
          {% render_table spaces_table %}
        </div>
      </div>
      <div class="card">
        <h5 class="card-header">Storage Sessions</h5>
        <div class="card-body table-responsive">
          {% render_table sessions_table %}
        </div>
      </div>
    </div>
  </div>
  {% endcomment %}
{% endblock content %}